\NeedsTeXFormat{LaTeX2e}
 
\ProvidesClass{Cours}[2015/09/01]

\LoadClass[11pt,french,oneside,openany]{book}
\RequirePackage[utf8]{inputenc}
\RequirePackage[T1]{fontenc}
\RequirePackage[a4paper,height=25cm,width=16cm]{geometry} 
\RequirePackage[greek,frenchb]{babel}
\RequirePackage{graphicx}
\RequirePackage{mathtools} 
\RequirePackage{fourier}
\RequirePackage{booktabs}
\RequirePackage{xcolor}
\RequirePackage{siunitx}
\RequirePackage{fp}%FPeval{\x}{3+2}

\RequirePackage{ifthen}
\RequirePackage{longtable}
\RequirePackage[version=4]{mhchem}%formules chimiques réaction /ce{}
\RequirePackage{esdiff}% Écriture rapide des dérivées
\RequirePackage{esvect}% vv{rot}
\RequirePackage{esint}% \iint
\RequirePackage{listings}% pour Python
\RequirePackage[mathscr]{eucal}
\RequirePackage{fancyhdr}
\RequirePackage{verbatim} % pour exclure réponse
\RequirePackage[Lenny]{fncychap}
\RequirePackage{caption}
\RequirePackage{enumitem}
\RequirePackage{ntheorem,thmtools}

\DeclareSymbolFont{grecant}{OML}{antt}{m}{n}
\DeclareMathSymbol{\mongamma}{\mathalpha}{grecant}{'015}

\setlength{\headheight}{15pt}% pour fancy
\setlength{\emergencystretch}{8em}

\sisetup{range-units=single,exponent-product=\cdot,output-decimal-marker={,},separate-uncertainty,range-phrase =~à~,inter-unit-product=\ensuremath{{}\cdot{}}}

\captionsetup{labelformat=simple}
\renewcommand{\thefigure}{\Alph{figure}} 

\everymath{\displaystyle}% Mode mathématique en ligne
\newcommand\ee{\mathrm{e}}
\newcommand\ii{\mathrm{j}}
\newcommand\uu{\underline}
\newcommand\vj{\vv \jmath}
\newcommand\dd{\mathop{}\mathopen{}\mathrm{d}}
\newcommand\conjug[1]{\underline{#1} ^{*}}
\newcommand\absc[1]{\mid \underline #1 \mid}
\newcommand{\gradN}[1]{\vv{\nabla} #1} % for gradient avec nabla
\newcommand{\divN}[1]{\vv{\nabla} \cdot \vec{#1}} % for divergence avec nabla
\newcommand{\rotN}[1]{\vv{\nabla} \times #1} % for curl avec nabla
\newcommand{\grad}[1]{\vv{\rm{grad}} \left( #1\right)} % for gradient
\newcommand{\rot}[1]{\vv{\rm{rot}} \left( #1 \right)} % for curl
\renewcommand{\div}[1]{\rm{div} \left( #1\right)} % for divergence
\renewcommand{\leq}{\leqslant}%signe inferieur ou egal francais
\renewcommand{\geq}{\geqslant}%signe superieur ou egal francais
\renewcommand{\L}[1]{\mathscr{L}\left(#1\right)}

\newcommand{\diffD}[2]{\frac{\mathrm{D}#1}{\mathrm{D}#2}}
\newcommand{\abs}[1]{\left\lvert #1 \right\rvert} % for absolute value
\newcommand{\avg}[1]{\left\langle #1 \right\rangle} % for average
\newcommand{\eps}{\varepsilon}
\renewcommand{\phi}{\varphi}
\renewcommand{\rho}{\varrho}
\renewcommand{\gamma}{\mongamma}
\newcommand\re[1]{\mathscr{R}e\left(#1\right)} % partie réelle
\newcommand\im[1]{\mathscr{I}m\left(#1\right)} % partie imaginaire
\newcommand\dtau{\mathrm{d}^3 \tau }
\newcommand\dS{\mathrm{d}^2 S}
\newcommand*\siecle[1]{\bsc{\romannumeral #1}\textsuperscript{e}~siècle}
\newcommand{\co}[2]{\ce{#1}~/~\ce{#2}}
\frenchbsetup{ItemLabeli=\textbullet}

\DeclareMathOperator{\sinc}{sinc}
\DeclareMathOperator{\erf}{erf}

\DeclareSIUnit\dec{décade}
\DeclareSIUnit\div{div}
\DeclareSIUnit\tour{tr}

\lstset{language=Python}

\newcommand{\avant}[3]{
\pscircle*[linecolor=white](#1,#2){6pt}
\pscircle(#1,#2){6pt}
\psdot[dotstyle=*,dotsize=4pt](#1,#2)
\uput[u](#1,#2){#3}

}
\newcommand{\arriere}[3]{
\pscircle*[linecolor=white](#1,#2){5pt}
\pscircle(#1,#2){5pt}
\psdot[dotstyle=BoldOtimes,dotsize=8pt](#1,#2)
\uput[u](#1,#2){#3}
}

\setlength{\emergencystretch}{8em}
\setlength{\headheight}{15pt}%pour fancy

\setcounter{secnumdepth}{3}
\renewcommand{\thesection}{\Roman{section}}
\renewcommand{\thesubsubsection}{\thesubsection.\alph{subsubsection}}
\renewcommand\arraystretch{1.3}

\definecolor{cli}{rgb}{1,1,0.3}
\definecolor{fer}{rgb}{0.8,0.8,0.8}

\newcommand{\imp}[1]{\centerline{\colorbox{cli}{#1}}}% Important, à retenir

\pagestyle{fancy}
\fancyfoot[R]{\thepage / \pageref{dernierepage}}


\author{JMM}
\date{}

\theorembodyfont{\normalfont}
\declaretheorem[title=Exemple]{Ex}

\RequirePackage{auto-pst-pdf}
\RequirePackage{pstricks}
\RequirePackage{multido}
\RequirePackage{pst-circ}%circuit électrique
\RequirePackage{pst-plot}%tracé de courbes
\RequirePackage{pst-math}%calcul  
\RequirePackage{pst-coil}%ressorts
\RequirePackage{pst-optic}% arrowLine
\RequirePackage{pst-3dplot}
\RequirePackage{pst-sigsys}%système linéaire
\RequirePackage{pstricks-add}%divers
\RequirePackage{pst-labo}%dessin
\RequirePackage{pst-node}
\RequirePackage{pst-sigsys}
\RequirePackage{pst-eucl}%angle

\psset{algebraic=true,arrowscale=1}

\endinput